@@ -1,6 +1,6 @@
 //
 //	srecord - manipulate eprom load files
-//	Copyright (C) 2000-2002 Peter Miller;
+//	Copyright (C) 2000-2004 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -25,15 +25,16 @@
 #include <arglex3.h>
 
 
-srec_cat_arglex3::srec_cat_arglex3(int argc, char **argv)
-        : srec_arglex(argc, argv)
+srec_cat_arglex3::srec_cat_arglex3(int argc, char **argv) :
+	srec_arglex(argc, argv)
 {
-	static table_ty table[] =
+	static const table_ty table[] =
 	{
 		{ "-Address_Length", token_address_length, },
 		{ "-Data_Only", token_data_only, },
 		{ "-Line_Length", token_line_length, },
 		{ "-HEAder", token_header, },
+		{ "-Start_Address", token_start_address, },
 		ARGLEX_END_MARKER
 	};
 
@@ -41,28 +42,6 @@ srec_cat_arglex3::srec_cat_arglex3(int argc, char **argv)
 }
 
 
-srec_cat_arglex3::srec_cat_arglex3()
-	: srec_arglex(0, 0)
-{
-	// bug
-}
-
-
-srec_cat_arglex3::srec_cat_arglex3(const srec_cat_arglex3 &)
-	: srec_arglex(0, 0)
-{
-	// bug
-}
-
-
-srec_cat_arglex3 &
-srec_cat_arglex3::operator=(const srec_cat_arglex3 &arg)
-{
-	// bug
-	return *this;
-}
-
-
 srec_cat_arglex3::~srec_cat_arglex3()
 {
 }
